Model for the evalUation of sea-LeveL risE and Temperature (Mullet)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

+----------------+-----------------+
| |CI CD|        | |PyPI Install|  |
+----------------+-----------------+
| |PyPI|         | |PyPI Version|  |
+----------------+-----------------+

Work in progress.

Brief summary
+++++++++++++

In its current form, this repository is meant to be a playground.
It provides a place to explore how a simple climate model could be written if it were to be written from scratch, combining the strengths of numerical computing languages (e.g. Fortran) and higher-level languages (e.g. Python).
Please feel free to make PRs or fork the repository for whatever purpose you like (it's under a BSD license to facilitate this).
The only request we currently make is that you don't use the model name (Mullet) in case we do one day turn this repository into a fully fledged model.

.. |CI CD| image:: https://github.com/znicholls/mullet/workflows/Mullet%20CI-CD/badge.svg
    :target: https://github.com/znicholls/mullet/actions?query=workflow%3A%22Mullet+CI-CD%22
.. |PyPI Install| image:: https://github.com/znicholls/mullet/workflows/Test%20PyPI%20install/badge.svg
    :target: https://github.com/znicholls/mullet/actions?query=workflow%3A%22Test+PyPI+install%22
.. |PyPI| image:: https://img.shields.io/pypi/pyversions/mullet.svg
    :target: https://pypi.org/project/mullet/
.. |PyPI Version| image:: https://img.shields.io/pypi/v/mullet.svg
    :target: https://pypi.org/project/mullet/
